@@ -6,7 +6,7 @@ package Amon2::Lite;
 use parent qw/Amon2 Amon2::Web/;
 use Router::Simple 0.04;
 use Text::Xslate;
-use Text::Xslate::Bridge::TT2Like;
+use Text::Xslate::Bridge::Star;
 use File::Spec;
 use File::Basename qw(dirname);
 use Data::Section::Simple ();
@@ -74,7 +74,7 @@ sub import {
         my $config = $caller->config->{'Text::Xslate'} || +{};
         my $xslate = Text::Xslate->new(+{
             'syntax'   => 'TTerse',
-            'module'   => [ 'Text::Xslate::Bridge::TT2Like' ],
+            'module'   => [ 'Text::Xslate::Bridge::Star' ],
             'path'     => [ $vpath, $tmpl_dir ],
             'function' => {
                 c        => sub { Amon2->context() },
